@@ -1,7 +1,7 @@
 package Perinci::Sub::To::FuncBase;
 
 our $DATE = '2016-02-26'; # DATE
-our $VERSION = '0.75'; # VERSION
+our $VERSION = '0.76'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -130,7 +130,7 @@ sub gen_doc_section_arguments {
     my $args_p = $meta->{args} // {};
 
     # perl term for args, whether '$arg1, $arg2, ...', or '%args', etc
-    my $aa = $meta->{args_as} // 'hash';
+    my $aa = $meta->{_orig_args_as} // 'hash';
     my $aplt;
     if (!keys(%$args_p)) {
         $aplt = '()';
@@ -226,7 +226,7 @@ Perinci::Sub::To::FuncBase - Base class for Perinci::Sub::To::* function documen
 
 =head1 VERSION
 
-This document describes version 0.75 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2016-02-26.
+This document describes version 0.76 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2016-02-26.
 
 =for Pod::Coverage .+
 
