@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
 our $DATE = '2016-02-26'; # DATE
-our $VERSION = '0.75'; # VERSION
+our $VERSION = '0.76'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -92,12 +92,12 @@ sub after_gen_doc {
                     unless $cares->[0] == 200;
                 $argsdump = Data::Dump::SortKeys::dump($cares->[2]);
                 unless ($orig_args_as =~ /ref/) {
-                    $argsdump =~ s/^\[\n*//; $argsdump =~ s/,?\s*\]\n?$//;
+                    $argsdump =~ s/\A\[\s*//s; $argsdump =~ s/,?\s*\]\s*\z//s;
                 }
             } else {
                 $argsdump = Data::Dump::SortKeys::dump($eg->{args});
                 unless ($orig_args_as =~ /ref/) {
-                    $argsdump =~ s/^\{\n*//; $argsdump =~ s/,?\s*\}\n?$//;
+                    $argsdump =~ s/\A\{\s*//s; $argsdump =~ s/,?\s*\}\s*\z//s;
                 }
             }
         } elsif ($eg->{argv}) {
@@ -406,7 +406,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.75 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-02-26.
+This document describes version 0.76 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-02-26.
 
 =head1 SYNOPSIS
 
